"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OperationLoggerInterceptor = void 0;
const rxjs_1 = require("rxjs");
const common_1 = require("@nestjs/common");
const executionContextUtils_1 = require("../executionContextUtils");
class OperationLoggerInterceptor {
    constructor(options) {
        this.options = options;
        this.loggerName = 'Operation logger';
        this.logger = new common_1.Logger(this.loggerName);
    }
    logOperationHttpContext(context, action, error) {
        this.logOperationDefaultContext(context, action, error);
    }
    logOperationRqmContext(context, action, error) {
        this.logOperationDefaultContext(context, action, error);
    }
    logOperationDefaultContext(context, action, error) {
        const { operation } = (0, executionContextUtils_1.getRouteInfo)(context);
        if (error)
            this.logger.error(`operation: ${operation}; ${action}: ${error}`);
        else
            this.logger.debug(`operation: ${operation}; ${action}`);
    }
    logOperation(context, action, error) {
        var _a, _b;
        const contextType = context.getType();
        if (contextType === 'rmq' && ((_a = this.options) === null || _a === void 0 ? void 0 : _a.applyForRqmContext))
            this.logOperationRqmContext(context, action, error);
        if (contextType === 'http' && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.applyForHttpContext))
            this.logOperationHttpContext(context, action, error);
    }
    intercept(context, next) {
        this.logOperation(context, 'starting');
        return next.handle().pipe((0, rxjs_1.tap)(() => {
            this.logOperation(context, 'success');
        }), (0, rxjs_1.catchError)((error) => {
            this.logOperation(context, 'error', error);
            throw error;
        }));
    }
}
exports.OperationLoggerInterceptor = OperationLoggerInterceptor;
//# sourceMappingURL=operationLogger.interceptor.js.map