"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrometheusLoggerInterceptor = void 0;
const axios_1 = require("axios");
const rxjs_1 = require("rxjs");
const common_1 = require("@nestjs/common");
const executionContextUtils_1 = require("../executionContextUtils");
const prometheusCounters_1 = require("../prometheusCounters");
class PrometheusLoggerInterceptor {
    constructor(options) {
        this.options = options;
        this.loggerName = 'Prometheus logger';
        this.logger = new common_1.Logger(this.loggerName);
    }
    logMetricHttpContext(context, error) {
        let code = error ? 0 : axios_1.HttpStatusCode.Ok;
        if (error instanceof common_1.HttpException)
            code = error.getStatus();
        const { controller, method } = (0, executionContextUtils_1.getRouteInfo)(context);
        prometheusCounters_1.metricHttpContext.inc({ code, controller, method });
    }
    logMetricRmqContext(context, error) {
        const { operation } = (0, executionContextUtils_1.getRouteInfo)(context);
        const result = error ? 'error' : 'success';
        prometheusCounters_1.metricRmqContext.inc({ operation, result });
    }
    logMetric(context, error) {
        var _a, _b;
        const contextType = context.getType();
        if (contextType === 'http' && ((_a = this.options) === null || _a === void 0 ? void 0 : _a.applyForHttpContext))
            this.logMetricHttpContext(context, error);
        if (contextType === 'rmq' && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.applyForRqmContext))
            this.logMetricRmqContext(context, error);
    }
    intercept(context, next) {
        return next.handle().pipe((0, rxjs_1.tap)(() => {
            this.logMetric(context, null);
        }), (0, rxjs_1.catchError)((error) => {
            this.logMetric(context, error);
            throw error;
        }));
    }
}
exports.PrometheusLoggerInterceptor = PrometheusLoggerInterceptor;
//# sourceMappingURL=prometheusLogger.interceptor.js.map