"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RabbitMessageLoggerInterceptor = void 0;
const rxjs_1 = require("rxjs");
const ulid_1 = require("ulid");
const common_1 = require("@nestjs/common");
class RabbitMessageLoggerInterceptor {
    constructor(trafficLogger) {
        this.trafficLogger = trafficLogger;
        this.loggerName = 'Raw Rabbit messages logger';
        this.logger = new common_1.Logger(this.loggerName);
    }
    getMessageDataFromContext(context) {
        var _a;
        const inputModel = context.getArgs().at(1);
        const message = (_a = inputModel === null || inputModel === void 0 ? void 0 : inputModel.content) === null || _a === void 0 ? void 0 : _a.toString();
        const metadata = inputModel === null || inputModel === void 0 ? void 0 : inputModel.fields;
        return { message, metadata };
    }
    logIncomingMessage(messageId, context) {
        this.trafficLogger
            .logRequestResponse(`${this.loggerName} -> incoming message ${messageId}`, {
            requestData: this.getMessageDataFromContext(context),
        })
            .catch((error) => {
            common_1.Logger.error(error);
        });
    }
    logSuccess(messageId, response) {
        this.trafficLogger
            .logRequestResponse(`${this.loggerName} -> incoming message ${messageId} (success)`, {
            responseData: { response },
        })
            .catch((error) => {
            common_1.Logger.error(error);
        });
    }
    logError(messageId, error) {
        this.trafficLogger
            .logRequestResponse(`${this.loggerName} -> incoming message ${messageId} (error)`, {
            responseData: { error, message: error === null || error === void 0 ? void 0 : error.message },
        })
            .catch((error) => {
            common_1.Logger.error(error);
        });
    }
    intercept(context, next) {
        const contextType = context.getType();
        if (contextType !== 'rmq')
            return next.handle();
        const messageId = (0, ulid_1.ulid)();
        this.logIncomingMessage(messageId, context);
        return next.handle().pipe((0, rxjs_1.tap)((response) => {
            this.logSuccess(messageId, response);
        }), (0, rxjs_1.catchError)((error) => {
            this.logError(messageId, error);
            throw error;
        }));
    }
}
exports.RabbitMessageLoggerInterceptor = RabbitMessageLoggerInterceptor;
//# sourceMappingURL=rabbitMessageLogger.interceptor.js.map