"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPrometheusLoggerMiddleware = void 0;
const common_1 = require("@nestjs/common");
const prometheusCounters_1 = require("../prometheusCounters");
const loggerName = 'Prometheus logger (middleware)';
const logger = new common_1.Logger(loggerName);
function createPrometheusLoggerMiddleware() {
    return (req, res, next) => {
        try {
            const originalSend = res.send;
            res.send = function (...args) {
                try {
                    const { statusCode } = res;
                    const { originalUrl, method } = req;
                    if (originalUrl !== '/prom-metrics' && originalUrl !== '/favicon.ico') {
                        prometheusCounters_1.metricHttpContextEndpoints.inc({ method, originalUrl, statusCode });
                    }
                }
                catch (error) {
                    logger.error(error);
                }
                return originalSend.apply(this, args);
            };
        }
        catch (error) {
            logger.error(error);
        }
        next();
    };
}
exports.createPrometheusLoggerMiddleware = createPrometheusLoggerMiddleware;
//# sourceMappingURL=prometheusLogger.middleware.js.map