"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRawRequestResponseLoggerMiddleware = void 0;
const common_1 = require("@nestjs/common");
const allowedMimeTypesForLogResponseBody = ['application/json', 'application/xml', 'text/json', 'text/xml', 'text/plain'];
const logResponseBody = (contentType) => {
    if (!contentType)
        return false;
    const lowerCaseContentType = contentType.toLowerCase();
    return allowedMimeTypesForLogResponseBody.some((mimeType) => lowerCaseContentType.includes(mimeType));
};
const loggerName = 'Raw request/reponse logger (middleware)';
const logger = new common_1.Logger(loggerName);
function createRawRequestResponseLoggerMiddleware(trafficLogger, options) {
    return (req, res, next) => {
        if (options === null || options === void 0 ? void 0 : options.logRequest) {
            const { method, originalUrl, headers, body } = req;
            trafficLogger
                .logRequestResponse(loggerName, {
                requestData: { method, originalUrl, headers, body },
            })
                .catch((error) => {
                logger.error(loggerName, error);
            });
        }
        if (options === null || options === void 0 ? void 0 : options.logResponse) {
            try {
                const originalSend = res.send;
                res.send = function (...args) {
                    var _a;
                    try {
                        const headers = res === null || res === void 0 ? void 0 : res.getHeaders();
                        const contentType = (_a = res === null || res === void 0 ? void 0 : res.getHeader('content-type')) === null || _a === void 0 ? void 0 : _a.toString();
                        let body = null;
                        if (logResponseBody(contentType)) {
                            body = args[0];
                        }
                        trafficLogger
                            .logRequestResponse(loggerName, {
                            responseData: { headers, statusCode: res.statusCode, body },
                        })
                            .catch((error) => {
                            logger.error(error);
                        });
                    }
                    catch (error) {
                        logger.error(error);
                    }
                    return originalSend.apply(this, args);
                };
            }
            catch (error) {
                logger.error(error);
            }
        }
        next();
    };
}
exports.createRawRequestResponseLoggerMiddleware = createRawRequestResponseLoggerMiddleware;
//# sourceMappingURL=rawRequestReponseLogger.middleware.js.map