"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CarrierQuery = void 0;
const qs_1 = require("qs");
const exceptions_1 = require("../exceptions");
class CarrierQuery {
    async processQuery(requestModel, client) {
        const { carrierId } = requestModel;
        const response = await client.get(`api/carriers?${this.createRequestQuery(carrierId)}`);
        const foundCarriersCount = response.data.meta.pagination.total;
        if (foundCarriersCount < 1)
            return null;
        if (foundCarriersCount > 1)
            throw new exceptions_1.UniqueViolationException(`Carrier ${carrierId} has been found mutiple times in CMS`);
        const carrierResponseData = response.data.data[0].attributes;
        return {
            carrierName: carrierResponseData.carrierName,
            carrierID: carrierResponseData.carrierID,
            code: carrierResponseData.code,
            trackingUrl: carrierResponseData.trackingUrl,
            trackingUrlEn: carrierResponseData.trackingUrlEn,
        };
    }
    createRequestQuery(carrierId) {
        return (0, qs_1.stringify)({
            filters: {
                carrierID: {
                    $eq: carrierId,
                },
            },
        }, {
            encodeValuesOnly: true,
        });
    }
}
exports.CarrierQuery = CarrierQuery;
//# sourceMappingURL=carrier.query.js.map