import { RabbitMQExchange, RabbitMQPattern } from './types';
import { IHealthStatusMessage, IOrderCancelMessage, IOrderCreateMessage, IOutputErrorMessage, ITrackingMessage } from './messages';
import { IOrderGetByIdMessage, IOrderGetByIdResponse } from './messages/orderGetById.interface';
import { IOrderUpdateMessage } from './messages/orderUpdate.interface';
export interface IRabbitMQServiceOptions {
    defaultRpcTimeoutMs?: number;
}
export interface IRabbitMQService {
    sendCreateOrderMessage: (message: IOrderCreateMessage) => void;
    sendSaveOrderMessage: (message: IOrderCreateMessage) => void;
    sendCancelOrderMessage: (message: IOrderCancelMessage) => void;
    sendUpdateOrderMessage: (message: IOrderUpdateMessage) => void;
    sendOutputOrderStatusMessage: (message: ITrackingMessage) => void;
    sendOutputErrorMessage: (message: IOutputErrorMessage) => void;
    sendOutputPrintLabelMessage: (message: ITrackingMessage) => void;
    sendHealthStatusMessage: (message: IHealthStatusMessage) => void;
    sendHealthCheckMessage: () => void;
    sendTrackingMessage: (message: ITrackingMessage) => void;
    sendTrackingRequeueMessage: (message: ITrackingMessage) => void;
    getOrderById: (message: IOrderGetByIdMessage) => Promise<IOrderGetByIdResponse>;
}
export interface IRabbitMQMessageType<TMessageType> {
    _messageType?: TMessageType;
}
export interface IRabbitMQResponseType<TResponseType> {
    _responseType?: TResponseType;
}
export interface IRabbitMQMessageDefinitionBase {
    exchange: RabbitMQExchange;
    routingKey: string;
}
export interface IRabbitMQMessageDefinition<TMessageType> extends IRabbitMQMessageDefinitionBase, IRabbitMQMessageType<TMessageType> {
}
export interface IRabbitMQMessageRpcDefinition<TMessageType, TResponseType> extends IRabbitMQMessageDefinition<TMessageType>, IRabbitMQResponseType<TResponseType> {
}
export interface IRabbitMQMessageWithPatternDefinition<TMessageType> extends IRabbitMQMessageDefinition<TMessageType> {
    pattern: RabbitMQPattern;
}
//# sourceMappingURL=rabbitmq.interface.d.ts.map